{% extends "admin/base_site.html" %}
{% load i18n admin_urls static admin_modify pcart_core %}

{% block extrahead %}{{ block.super }}
<script type="text/javascript" src="{% url 'admin:jsi18n' %}"></script>
{{ media }}
{% endblock %}

{% block extrastyle %}{{ block.super }}<link rel="stylesheet" type="text/css" href="{% static "admin/css/forms.css" %}" />{% endblock %}

{% block coltype %}colM{% endblock %}

{% block bodyclass %}{{ block.super }} app-{{ opts.app_label }} model-{{ opts.model_name }} change-form{% endblock %}

{% if not is_popup %}
{% block breadcrumbs %}
<div class="breadcrumbs">
<a href="{% url 'admin:index' %}">{% trans 'Home' %}</a>
&rsaquo; <a href="{% url 'admin:app_list' app_label=opts.app_label %}">{{ opts.app_config.verbose_name }}</a>
&rsaquo; {% if has_change_permission %}<a href="{% url opts|admin_urlname:'changelist' %}">{{ opts.verbose_name_plural|capfirst }}</a>{% else %}{{ opts.verbose_name_plural|capfirst }}{% endif %}
&rsaquo; {% if add %}{% blocktrans with name=opts.verbose_name %}Add {{ name }}{% endblocktrans %}{% else %}{{ original|truncatewords:"18" }}{% endif %}
</div>
{% endblock %}
{% endif %}

{% block content %}<div id="content-main">
{% block object-tools %}
{% if change %}{% if not is_popup %}
  <ul class="object-tools">
    {% block object-tools-items %}
    <li>
        {% url opts|admin_urlname:'history' original.pk|admin_urlquote as history_url %}
        <a href="{% add_preserved_filters history_url %}" class="historylink">{% trans "History" %}</a>
    </li>
    {% if has_absolute_url %}<li><a href="{{ absolute_url }}" class="viewsitelink">{% trans "View on site" %}</a></li>{% endif %}
    {% endblock %}
  </ul>
{% endif %}{% endif %}
{% endblock %}

<form {% if has_file_field %}enctype="multipart/form-data" {% endif %}action="{{ form_url }}" method="post" id="{{ opts.model_name }}_form" novalidate>{% csrf_token %}{% block form_top %}{% endblock %}
<div>
{% if is_popup %}<input type="hidden" name="{{ is_popup_var }}" value="1" />{% endif %}
{% if to_field %}<input type="hidden" name="{{ to_field_var }}" value="{{ to_field }}" />{% endif %}
{% if save_on_top %}{% block submit_buttons_top %}{% submit_row %}{% endblock %}{% endif %}
{% if errors %}
    <p class="errornote">
    {% if errors|length == 1 %}{% trans "Please correct the error below." %}{% else %}{% trans "Please correct the errors below." %}{% endif %}
    </p>
    {{ adminform.form.non_field_errors }}
    {% if adminform.form.settings_fields %}{{errors}}{% endif %}
{% endif %}

{% block field_sets %}
{% for fieldset in adminform %}
  {% include "admin/includes/fieldset.html" %}
{% endfor %}
{% endblock %}

{% for field_group in adminform.form.settings_fields %}
<fieldset class="module aligned {{ field_group }}">
    {% if field_group.name %}<h2 style="font-weight:bold;">{{ field_group.name }}</h2>{% endif %}
    {% for option in field_group.settings %}
        {% if option.type == "paragraph" %}
            {{ option.content|markdown }}
        {% elif option.type == "header" %}
            <p style="background-color:#eee;padding:3px;font-size:120%;">{{ option.content }}</p>
        {% elif option.type == "checkbox" %}
            <div class="form-row field-{{option.id}}">
                <div class="checkbox-row">
                    <input {% if option.value %}checked="checked"{% endif %} id="id_{{option.id}}" name="{{option.id}}" type="checkbox">
                    <label class="vCheckboxLabel" for="id_{{option.id}}">{{option.label}}</label>
                    {% if option.info %}<p class="help">{{option.info}}</p>{% endif %}
                </div>
            </div>
        {% elif option.type == "radio" or option.type == "select" %}
            <div class="form-row field-{{option.id}}">
                <div>
                    <label for="id_{{option.id}}">{{option.label|markdown}}</label>
                    <select id="id_{{option.id}}" name="{{option.id}}">
                        {% regroup option.options by group as options %}
                        {% for option in options %}
                        {% if option.grouper %}<optgroup label="{{option.grouper}}">{% endif %}
                        {% for o in option.list %}<option value="{{o.value}}">{{o.label}}</option>{% endfor %}
                        {% if option.grouper %}</optgroup>{% endif %}
                        {% endfor %}
                    </select>
                    {% if option.info %}<p class="help">{{option.info}}</p>{% endif %}
                </div>
            </div>
        {% elif option.type == "text" or option.type == "color" or option.type == "collection" or option.type == "blog" or option.type == "link_list" %}
            <div class="form-row field-{{option.id}}">
                <div>
                    <label for="id_{{option.id}}">{{option.label|markdown}}</label>
                    <input type="text" id="id_{{option.id}}" name="{{option.id}}" value="{{option.value}}">
                    {% if option.info %}<p class="help">{{option.info}}</p>{% endif %}
                </div>
            </div>
        {% elif option.type == "textarea" %}
            <div class="form-row field-{{option.id}}">
                <div>
                    <label for="id_{{option.id}}">{{option.label|markdown}}</label>
                    <textarea id="id_{{option.id}}" name="{{option.id}}">{{option.value}}</textarea>
                    {% if option.info %}<p class="help">{{option.info}}</p>{% endif %}
                </div>
            </div>
        {% elif option.type == "image" %}
            <div class="form-row field-{{option.id}}">
                <div>
                    <label for="id_{{option.id}}">{{option.label|markdown}}</label>
                    {% if option.value %}
                    <p class="file-upload">{% trans "Currently" %}:
                        <a href="{{option.url}}">{{option.value}}</a>
                        <span class="clearable-file-input">
                            <input id="{{option.id}}-clear_id" name="{{option.id}}-clear" type="checkbox">
                            <label for="{{option.id}}-clear_id">{% trans "Clear" %}</label>
                        </span>
                        <br>
                    {% endif %}
                    <input type="file" id="id_{{option.id}}" name="{{option.id}}" value="{{option.id}}">
                    {% if option.info %}<p class="help">{{option.info}}</p>{% endif %}
                    {% if option.value %}</p>{% endif %}
                </div>
            </div>
        {% endif %}
    {% endfor %}
</fieldset>
{% endfor %}

{% block after_field_sets %}{% endblock %}

{% block inline_field_sets %}
{% for inline_admin_formset in inline_admin_formsets %}
    {% include inline_admin_formset.opts.template %}
{% endfor %}
{% endblock %}

{% block after_related_objects %}{% endblock %}

{% block submit_buttons_bottom %}{% submit_row %}{% endblock %}

{% block admin_change_form_document_ready %}
    <script type="text/javascript"
            id="django-admin-form-add-constants"
            src="{% static 'admin/js/change_form.js' %}"
            {% if adminform and add %}
                data-model-name="{{ opts.model_name }}"
            {% endif %}>
    </script>
{% endblock %}

{# JavaScript for prepopulated fields #}
{% prepopulated_fields_js %}

</div>
</form></div>
{% endblock %}
